@@ -16,7 +16,7 @@ class ParamsQuerySet(AuditQuerySet):
     def get_params(self, request, *args):
         request = DSRequest(request=request)
         data = request.get_data()
-        if data == None or data.get('user_id') == None:
+        if data is None or data.get('user_id') is None:
             return []
 
         # app_id = data.get('app_id')
@@ -41,7 +41,7 @@ class ParamsQuerySet(AuditQuerySet):
     def get_params_key(self, request, *args):
         request = DSRequest(request=request)
         data = request.get_data()
-        if data == None:
+        if data is None:
             return '???'
 
         key = data.get('key')
@@ -55,8 +55,8 @@ class ParamsManager(AuditManager):
     def get_queryset(self):
         return ParamsQuerySet(self.model, using=self._db)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'key': record.key[1:len(record.key) - 1] if record.key[0:1] == "'" else record.key,
@@ -65,8 +65,8 @@ class ParamsManager(AuditManager):
         }
         return res
 
-    @staticmethod
-    def getRecord1(record):
+    @classmethod
+    def getRecord1(cls, record):
         res = {
             'id': record.id,
             'key': record.key[1:len(record.key) - 1] if record.key[0:1] == "'" else record.key,
@@ -94,12 +94,12 @@ class ParamsManager(AuditManager):
         user_id = data.get('user_id')
 
         res = data
-        if key != None and user_id != None:
+        if key is not None and user_id is not None:
             if key[0:1] == "'":
                 key = key[1:len(key) - 1]
             setAttr(data, 'key', key)
 
-            if value == None or value == '':
+            if value is None or value == '':
                 res = super().filter(
                     user_id=user_id,
                     key=key
