@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import Model
+from django.db.models import Model, BigAutoField
 from transliterate import translit
 from transliterate.exceptions import LanguageDetectionError
 
@@ -10,6 +10,7 @@ logger = logging.getLogger(__name__)
 
 
 class Entity_1c(Model):
+    id = BigAutoField(primary_key=True, verbose_name="Идентификатор")
     code = CodeField(unique=True)
 
     @property
